@@ -19,10 +19,11 @@
  * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  *
- * $Id: libspeechd.h,v 1.26 2008-02-08 10:01:09 hanke Exp $
+ * $Id: libspeechd.h,v 1.29 2008-07-30 09:47:00 hanke Exp $
  */
 
-#define _GNU_SOURCE
+#ifndef _LIBSPEECHD_H
+#define _LIBSPEECHD_H
 
 #include <stdio.h>
 #include <stddef.h>
@@ -77,7 +78,14 @@ typedef enum{
     SPD_CHILD_MALE = 7,
     SPD_CHILD_FEMALE = 8
 }SPDVoiceType;
-    
+
+
+typedef struct{
+  char *name;   /* Name of the voice (id) */
+  char *language;  /* 2-letter ISO language code */
+  char *variant;   /* a not-well defined string describing dialect etc. */
+}SPDVoice;
+
 typedef enum{
     SPD_BEGIN = 1,
     SPD_END = 2,
@@ -181,6 +189,10 @@ int spd_set_voice_type(SPDConnection*, SPDVoiceType type);
 int spd_set_voice_type_all(SPDConnection*, SPDVoiceType type);
 int spd_set_voice_type_uid(SPDConnection*, SPDVoiceType type, unsigned int uid);
 
+int spd_set_synthesis_voice(SPDConnection*, const char *voice_name);
+int spd_set_synthesis_voice_type_all(SPDConnection*, const char *voice_name);
+int spd_set_synthesis_voice_type_uid(SPDConnection*, const char *voice_name, unsigned int uid);
+
 int spd_set_data_mode(SPDConnection *connection, SPDDataMode mode);
 
 int spd_set_notification_on(SPDConnection* connection, SPDNotification notification);
@@ -222,6 +234,11 @@ int spd_set_output_module_uid(SPDConnection* connection, const char* output_modu
 int spd_get_client_list(SPDConnection *connection, char **client_names, int *client_ids, int* active);
 int spd_get_message_list_fd(SPDConnection *connection, int target, int *msg_ids, char **client_names);
 
+char** spd_list_modules(SPDConnection *connection);
+char** spd_list_voices(SPDConnection *connection);
+SPDVoice** spd_list_synthesis_voices(SPDConnection *connection);
+char** spd_execute_command_with_list_reply(SPDConnection *connection, char* command);
+
 
 /* Direct SSIP communication */
 int spd_execute_command(SPDConnection* connection, char* command);
@@ -235,3 +252,5 @@ char* spd_send_data_wo_mutex(SPDConnection *connection, const char *message, int
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
+
+#endif /* ifndef _LIBSPEECHD_H */
