@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  *
- * $Id: generic.c,v 1.25 2007/02/27 17:38:12 hanke Exp $
+ * $Id: generic.c,v 1.30 2008-07-30 09:15:51 hanke Exp $
  */
 
 #include <glib.h>
@@ -30,7 +30,7 @@
 #include "module_utils_addvoice.c"
 
 #define MODULE_NAME     "generic"
-#define MODULE_VERSION  "0.1"
+#define MODULE_VERSION  "0.2"
 
 DECLARE_DEBUG();
 
@@ -60,12 +60,16 @@ void generic_set_pitch(signed int pitch);
 void generic_set_voice(EVoiceType voice);
 void generic_set_language(char* language);
 void generic_set_volume(signed int volume);
+void generic_set_punct(EPunctMode punct);
 
 /* Fill the module_info structure with pointers to this modules functions */
 
 MOD_OPTION_1_STR(GenericExecuteSynth);
 MOD_OPTION_1_INT(GenericMaxChunkLength);
 MOD_OPTION_1_STR(GenericDelimiters);
+MOD_OPTION_1_STR(GenericPunctNone);
+MOD_OPTION_1_STR(GenericPunctSome);
+MOD_OPTION_1_STR(GenericPunctAll);
 MOD_OPTION_1_STR(GenericStripPunctChars);
 MOD_OPTION_1_STR(GenericRecodeFallback);
 
@@ -85,6 +89,7 @@ static char generic_msg_rate_str[16];
 static char generic_msg_volume_str[16];
 static char* generic_msg_voice_str = NULL;
 static TGenericLanguage* generic_msg_language = NULL;
+static char* generic_msg_punct_str;
 
 /* Public functions */
 int
@@ -99,7 +104,7 @@ module_load(void)
 
     MOD_OPTION_1_INT_REG(GenericMaxChunkLength, 300);
     MOD_OPTION_1_STR_REG(GenericDelimiters, ".");
-    MOD_OPTION_1_STR_REG(GenericStripPunctChars, "~@#$%^&*+=|\\/<>[]_");
+    MOD_OPTION_1_STR_REG(GenericStripPunctChars, "");
     MOD_OPTION_1_STR_REG(GenericRecodeFallback, "?");
 
     MOD_OPTION_1_INT_REG(GenericRateAdd, 0);
@@ -117,6 +122,11 @@ module_load(void)
 
     MOD_OPTION_HT_REG(GenericLanguage);
 
+    MOD_OPTION_1_STR_REG(GenericPunctNone, "--punct-none");
+    MOD_OPTION_1_STR_REG(GenericPunctSome, "--punct-some");
+    MOD_OPTION_1_STR_REG(GenericPunctAll, "--punct-all");
+
+
     module_register_settings_voices();
 
     return 0;
@@ -157,6 +167,19 @@ module_init(char **status_info)
     return 0;
 }
 
+int
+module_audio_init(char **status_info){
+  status_info = NULL;
+  return 0;
+}
+
+
+VoiceDescription**
+module_list_voices(void)
+{
+  return NULL;
+}
+
 
 int
 module_speak(gchar *data, size_t bytes, EMessageType msgtype)
@@ -175,6 +198,7 @@ module_speak(gchar *data, size_t bytes, EMessageType msgtype)
 
     UPDATE_STRING_PARAMETER(language, generic_set_language);
     UPDATE_PARAMETER(voice, generic_set_voice);
+    UPDATE_PARAMETER(punctuation_mode, generic_set_punct);
     UPDATE_PARAMETER(pitch, generic_set_pitch);
     UPDATE_PARAMETER(rate, generic_set_rate);
     UPDATE_PARAMETER(volume, generic_set_volume);
@@ -197,7 +221,10 @@ module_speak(gchar *data, size_t bytes, EMessageType msgtype)
 
     if (tmp == NULL) return -1;
 
-    *generic_message = module_strip_ssml(tmp);
+    if (msgtype == MSGTYPE_TEXT)
+      *generic_message = module_strip_ssml(tmp);
+    else
+      *generic_message = strdup(tmp);
     xfree(tmp);
 
     module_strip_punctuation_some(*generic_message, GenericStripPunctChars);
@@ -265,6 +292,8 @@ module_close(int status)
 
 /* Internal functions */
 
+/* Replace all occurances of 'token' in 'sting'
+   with 'data' */
 char*
 string_replace(char *string, char* token, char* data)
 {
@@ -272,20 +301,26 @@ string_replace(char *string, char* token, char* data)
     char *str1;
     char *str2;
     char *new;
+    char *mstring;
 
-    /* Split the string in two parts, ommit the token */
-    p = strstr(string, token);
-    if (p == NULL) return string;
-    *p = 0;
+    mstring = g_strdup(string);
+    while (1){
+      /* Split the string in two parts, ommit the token */
+      p = strstr(mstring, token);
+      if (p == NULL){
+	return mstring;
+      }
+      *p = 0;
 
-    str1 = string;
-    str2 = p + (strlen(token));        
+      str1 = mstring;
+      str2 = p + (strlen(token));        
 
-    /* Put it together, replacing token with data */
-    new = g_strdup_printf("%s%s%s", str1, data, str2);
-    free(string);
+      /* Put it together, replacing token with data */
+      new = g_strdup_printf("%s%s%s", str1, data, str2);
+      xfree(mstring);
+      mstring = new;
+    }
 
-    return new;
 }
 
 void*
@@ -335,17 +370,49 @@ _generic_speak(void* nothing)
             {
 		char *e_string;
 		char *p;	       
+		char *tmpdir, *homedir;
+		char *helper;
+		char *play_command;
 		
+		helper = getenv("TMPDIR");
+		if (helper)
+		  tmpdir = strdup(helper);
+		else
+		  tmpdir = strdup("/tmp");
+
+		helper = g_get_home_dir();
+		if (helper)
+		  homedir = strdup(helper);
+		else
+		  homedir = strdup("UNKNOWN_HOME_DIRECTORY");
+
+		if (!strcmp(audio_settings.audio_output_method, "oss")){
+		  play_command = strdup("play");
+		}else if (!strcmp(audio_settings.audio_output_method, "alsa")){
+		  play_command = strdup("aplay");
+		}else if (!strcmp(audio_settings.audio_output_method, "pulse")){
+		  play_command = strdup("paplay");
+		}else{
+		  assert("Unknown audio output method requested");
+		}
+
 		/* Set this process as a process group leader (so that SIGKILL
 		   is also delivered to the child processes created by system()) */
 		if (setpgid(0,0) == -1) DBG("Can't set myself as project group leader!");
 
 		e_string = strdup(GenericExecuteSynth);
 
+		e_string = string_replace(e_string, "$PLAY_COMMAND", play_command);
+		xfree(play_command);
+		e_string = string_replace(e_string, "$TMPDIR", tmpdir);
+		xfree(tmpdir);
+		e_string = string_replace(e_string, "$HOMEDIR", homedir);
+		xfree(homedir);
 		e_string = string_replace(e_string, "$PITCH", generic_msg_pitch_str);
 		e_string = string_replace(e_string, "$RATE", generic_msg_rate_str);
 		e_string = string_replace(e_string, "$VOLUME", generic_msg_volume_str);
 		e_string = string_replace(e_string, "$LANGUAGE", generic_msg_language->name);
+ 		e_string = string_replace(e_string, "$PUNCT", generic_msg_punct_str);
 		if (generic_msg_voice_str != NULL)
 		    e_string = string_replace(e_string, "$VOICE", generic_msg_voice_str);
 		else
@@ -432,7 +499,9 @@ _generic_child(TModuleDoublePipe dpipe, const size_t maxlen)
                 message = g_string_append(message, "\\\"");
             else if (text[i] == '`')
                 message = g_string_append(message, "\\`");
-            else{
+            else if (text[i] == '\\')
+                message = g_string_append(message, "\\\\");
+	    else{
                 g_string_append_printf(message, "%c", text[i]);
             }
         }
@@ -548,8 +617,27 @@ generic_set_voice(EVoiceType voice)
     generic_msg_voice_str = module_getvoice(generic_msg_language->code, voice);
     if (generic_msg_voice_str == NULL){
 	DBG("Invalid voice type specified or no voice available!");
+    }	
+}
+
+void
+generic_set_punct(EPunctMode punct)
+{
+    if (punct == PUNCT_NONE){
+        generic_msg_punct_str = strdup((char*) GenericPunctNone);
+	return;
+    }
+    else if (punct == PUNCT_SOME){
+	generic_msg_punct_str = strdup((char*) GenericPunctSome);
+	return;
+    }
+    else if (punct == PUNCT_ALL){
+	generic_msg_punct_str = strdup((char*) GenericPunctAll);
+	return;
+    }
+    else{
+	DBG("ERROR: Unknown punctuation setting, ignored");
     }
-	
 }
 
 #include "module_main.c"
