@@ -18,7 +18,7 @@
  * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  * 02110-1301, USA.
  *
- * $Id: module_main.c,v 1.14 2008-02-11 14:00:48 hanke Exp $
+ * $Id: module_main.c,v 1.16 2008-06-27 12:29:26 hanke Exp $
  */
 
 /* So that gcc doesn't comply */
@@ -37,6 +37,19 @@ if (!strcmp(cmd_buf, #command"\n")){ \
  fflush(stdout); \
 }
 
+#define PROCESS_CMD_W_ARGS(command, function) \
+if (!strncmp(cmd_buf, #command, strlen(#command))){	\
+ char *msg; \
+ pthread_mutex_lock(&module_stdout_mutex); \
+ if (printf("%s\n", msg = (char*) function(cmd_buf)) < 0){ \
+     DBG("Broken pipe, exiting...\n"); \
+     module_close(2); \
+ } \
+ pthread_mutex_unlock(&module_stdout_mutex);\
+ xfree(msg); \
+ fflush(stdout); \
+}
+
 #define PROCESS_CMD_NRP(command, function) \
 if (!strcmp(cmd_buf, #command"\n")){ \
  pthread_mutex_lock(&module_stdout_mutex); \
@@ -139,7 +152,9 @@ main(int argc, char *argv[])
         else PROCESS_CMD_NRP(PAUSE, do_pause) 
         else PROCESS_CMD(LIST VOICES, do_list_voices)
         else PROCESS_CMD(SET, do_set) 
-        else PROCESS_CMD(QUIT, do_quit) 
+        else PROCESS_CMD(AUDIO, do_audio) 
+	else PROCESS_CMD_W_ARGS(DEBUG, do_debug)
+        else PROCESS_CMD_NRP(QUIT, do_quit) 
         else{
           printf("300 ERR UNKNOWN COMMAND\n"); 
           fflush(stdout);
