@@ -1,4 +1,4 @@
-# Copyright (C) 2003-2007 Brailcom, o.p.s.
+# Copyright (C) 2003-2008 Brailcom, o.p.s.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -381,9 +381,12 @@ class SSIPClient(object):
             multiple connections, this can be used to identify each of them.
           user -- user identification string (user name).  When multi-user
             acces is expected, this can be used to identify their connections.
-          host -- server hostname or IP address as a string.
+          host -- server hostname or IP address as a string.  If None, the
+            default value is taken from SPEECHD_HOST environment variable (if it
+            exists) or from the DEFAULT_SPEECHD_HOST attribute of this class.
           port -- server port as number or None.  If None, the default value is
-            determined by the SPEECH_PORT attribute of this class.
+            taken from SPEECHD_PORT environment variable (if it exists) or from the
+            DEFAULT_SPEECHD_PORT attribute of this class.
         
         For more information on client identification strings see Speech
         Dispatcher documentation.
@@ -745,6 +748,46 @@ class SSIPClient(object):
         assert isinstance(value, int)
         self._conn.send_command('SET', scope, 'PAUSE_CONTEXT', value)
 
+    def set_debug(self, val):
+        """Switch debugging on and off. When switched on,
+        debugging files will be created in the chosen destination
+        (see set_debug_destination()) for Speech Dispatcher and all
+        its running modules. All logging information will then be
+        written into these files with maximal verbosity until switched
+        off. You should always first call set_debug_destination.
+
+        The intended use of this functionality is to switch debuging
+        on for a period of time while the user will repeat the behavior
+        and then send the logs to the appropriate bug-reporting place.
+
+        Arguments:
+          val -- a boolean value determining whether debugging
+                 is switched on or off
+          scope -- see the documentaion of this class.
+        
+        """
+        assert isinstance(val, bool)
+        if val == True:
+            ssip_val = "ON"
+        else:
+            ssip_val = "OFF"
+
+        self._conn.send_command('SET', scope.ALL, 'DEBUG', ssip_val)
+
+
+    def set_debug_destination(self, path):
+        """Set debug destination.
+
+        Arguments:
+          path -- path (string) to the directory where debuging
+                  files will be created
+          scope -- see the documentaion of this class.
+        
+        """
+        assert isinstance(val, string)
+
+        self._conn.send_command('SET', scope.ALL, 'DEBUG_DESTINATION', val)
+
     def block_begin(self):
         """Begin an SSIP block.
 
