@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  *
- * $Id: msg.h,v 1.29 2008-02-01 11:23:35 hanke Exp $
+ * $Id: msg.h,v 1.31 2008-07-01 08:50:46 hanke Exp $
  */
 
 #ifndef MSG_H
@@ -81,6 +81,8 @@
 #define OK_INSIDE_BLOCK                         "260 OK INSIDE BLOCK\r\n"
 #define OK_OUTSIDE_BLOCK                        "261 OK OUTSIDE BLOCK\r\n"
 
+#define OK_DEBUGGING                            "262 OK DEBUGGING SET\r\n"
+
 #define OK_NOT_IMPLEMENTED                      "299 OK BUT NOT IMPLEMENTED -- DOES NOTHING\r\n"
 
 #define ERR_NO_CLIENT				"401 ERR NO CLIENT\r\n"
@@ -114,6 +116,8 @@
 #define ERR_COULDNT_SET_VOLUME                  "314 ERR COULDNT SET VOLUME\r\n"
 #define ERR_COULDNT_SET_SSML_MODE               "315 ERR COULDNT SET SSML MODE\r\n"
 #define ERR_COULDNT_SET_NOTIFICATION            "316 ERR COULDNT SET NOTIFICATION\r\n"
+#define ERR_COULDNT_SET_DEBUGGING               "317 ERR COULDNT SET DEBUGGING\r\n"
+
 
 #define ERR_NO_SND_ICONS                        "320 ERR NO SOUND ICONS\r\n"
 #define ERR_CANT_REPORT_VOICES                  "321 ERR MODULE CANT REPORT VOICES\r\n"
