@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  *
- * $Id: parse.c,v 1.71 2008-02-11 14:01:42 hanke Exp $
+ * $Id: parse.c,v 1.73 2008-07-01 08:52:31 hanke Exp $
  */
 
 #include <ctype.h>
@@ -572,6 +572,8 @@ parse_set(const char *buf, const int bytes, const int fd)
     else SSIP_ON_OFF_PARAM(ssml_mode,
 	    OK_SSML_MODE_SET, ERR_COULDNT_SET_SSML_MODE,
 	    ALLOWED_INSIDE_BLOCK())
+      else SSIP_ON_OFF_PARAM(debug, g_strdup_printf("262-%s\r\n"OK_DEBUGGING, SpeechdOptions.debug_destination),
+            ERR_COULDNT_SET_DEBUGGING, ;)
     else if (TEST_CMD(set_sub, "notification")){
 	char *scope;
         char *par_s;
