@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  *
- * $Id: set.c,v 1.43 2007-11-05 09:17:56 hanke Exp $
+ * $Id: set.c,v 1.46 2008-07-01 09:00:32 hanke Exp $
  */
 
 #include <fnmatch.h>
@@ -103,6 +103,7 @@ set_rate_uid(int uid, int rate)
 
 SET_SELF_ALL(int, pitch);
 
+
 int
 set_pitch_uid(int uid, int pitch)
 {
@@ -367,11 +368,46 @@ set_ssml_mode_uid(int uid, int ssml_mode)
     return 0;
 }
 
+SET_SELF_ALL(int, debug);
+int
+set_debug_uid(int uid, int debug)
+{
+  char *debug_logfile_path;
+
+  /* Do not switch debugging on when already on
+     and vice-versa */
+  if (SpeechdOptions.debug && debug) return 1;
+  if (!SpeechdOptions.debug && !debug) return 1;
+ 
+  if (debug){
+    debug_logfile_path = g_strdup_printf("%s/speechd.log", SpeechdOptions.debug_destination);
+
+    debug_logfile = fopen(debug_logfile_path, "w");
+    if (debug_logfile == NULL){
+      MSG(3, "Error: can't open additional debug logging file %s!\n",
+	      debug_logfile_path);
+      return 1;
+    }
+    SpeechdOptions.debug = debug;
+    
+    spd_free(debug_logfile_path);
+    
+    /* Redirecting debugging for all output modules */
+    speechd_modules_debug();
+  }else{
+    SpeechdOptions.debug = 0;
+    speechd_modules_nodebug();
+    fclose(debug_logfile);
+  }
+  return 0;
+}
+
 #define SET_NOTIFICATION_STATE(state) \
 	if (val) \
 	    settings->notification = settings->notification | NOTIFY_ ## state; \
         else \
 	    settings->notification = settings->notification & (! NOTIFY_ ## state); 
+
 int
 set_notification_self(int fd, char *type, int val)
 {
@@ -407,7 +443,7 @@ set_notification_self(int fd, char *type, int val)
 	    SET_NOTIFICATION_STATE(RESUME);
 	}
     else 
-	return -1;
+	return 1;
 
     return 0;
 
