@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  *
- * $Id: speechd.c,v 1.77 2008-02-11 14:01:57 hanke Exp $
+ * $Id: speechd.c,v 1.81 2008-07-10 15:36:49 hanke Exp $
  */
 
 #include <gmodule.h>
@@ -40,7 +40,6 @@
 #include "server.h"
 
 /* Glib g_makedir */
-
 int  g_mkdir      (const gchar *filename, int mode);
 /* Manipulating pid files */
 int create_pid_file();
@@ -120,6 +119,10 @@ MSG2(int level, char *kind, char *format, ...)
 		  fprintf(custom_logfile, "[%s : %d] speechd: ",
 			  tstr, (int) tv.tv_usec);
                 }
+                if(SpeechdOptions.debug) {
+		  fprintf(debug_logfile, "[%s : %d] speechd: ",
+			  tstr, (int) tv.tv_usec);
+                }
 		spd_free(tstr);
             }
             for(i=1;i<level;i++){
@@ -140,6 +143,13 @@ MSG2(int level, char *kind, char *format, ...)
                 fprintf(custom_logfile, "\n");
                 fflush(custom_logfile);
             }
+	    if (SpeechdOptions.debug){
+	      va_start(args, format);	   
+	      vfprintf(debug_logfile, format, args);
+	      va_end(args);
+	      fprintf(debug_logfile, "\n");
+	      fflush(debug_logfile);
+	    }
         }
         if(std_log) {
             va_end(args);
@@ -154,16 +164,16 @@ MSG2(int level, char *kind, char *format, ...)
 /* The main logging function for Speech Dispatcher,
    level is between 1 and 5. 1 means the most important.*/
 /* TODO: Define this in terms of MSG somehow. I don't
-   know how to pass ... arguments to another C function */
+   know how to pass '...' arguments to another C function */
 void
 MSG(int level, char *format, ...)
 {
 
-    if(level <= SpeechdOptions.log_level) {
+  if((level <= SpeechdOptions.log_level)
+     || (SpeechdOptions.debug)) {
         va_list args;
         int i;
 	pthread_mutex_lock(&logging_mutex);		
-	va_start(args, format);
         {
             {
                 /* Print timestamp */
@@ -177,20 +187,35 @@ MSG(int level, char *format, ...)
 		assert(tstr);
 		assert(strlen(tstr)>1);
 		tstr[strlen(tstr)-1] = 0;
-		fprintf(logfile, "[%s : %d] speechd: ",
-			tstr, (int) tv.tv_usec);
+		if (level <= SpeechdOptions.log_level)
+		  fprintf(logfile, "[%s : %d] speechd: ",
+			  tstr, (int) tv.tv_usec);
+		if (SpeechdOptions.debug)
+		  fprintf(debug_logfile, "[%s : %d] speechd: ",
+			  tstr, (int) tv.tv_usec);
 		/*                fprintf(logfile, "[%s : %d] speechd: ",
 				  tstr, (int) tv.tv_usec);*/
 		spd_free(tstr);
             }
+	    
             for(i=1;i<level;i++){
 	      fprintf(logfile, " ");
             }
-            vfprintf(logfile, format, args);
-            fprintf(logfile, "\n");
-            fflush(logfile);
+	    if (level <= SpeechdOptions.log_level){
+	      va_start(args, format);	    
+	      vfprintf(logfile, format, args);
+	      va_end(args);
+	      fprintf(logfile, "\n");
+	      fflush(logfile);
+	    }
+	    if (SpeechdOptions.debug){
+	      va_start(args, format);	   
+	      vfprintf(debug_logfile, format, args);
+	      va_end(args);
+	      fprintf(debug_logfile, "\n");
+	      fflush(debug_logfile);
+	    }
         }
-        va_end(args);
 	pthread_mutex_unlock(&logging_mutex);		
     }				
 }
@@ -350,6 +375,39 @@ speechd_modules_reload(gpointer key, gpointer value, gpointer user)
     return;
 }
 
+void
+speechd_module_debug(gpointer key, gpointer value, gpointer user)
+{
+    OutputModule *module;
+
+    module = (OutputModule *) value;
+    if (module == NULL){
+        MSG(2,"Empty module, internal error");
+        return;
+    }
+ 
+    output_module_debug(module);		       
+
+    return;
+}
+
+
+void
+speechd_module_nodebug(gpointer key, gpointer value, gpointer user)
+{
+    OutputModule *module;
+
+    module = (OutputModule *) value;
+    if (module == NULL){
+        MSG(2,"Empty module, internal error");
+        return;
+    }
+ 
+    output_module_nodebug(module);		       
+
+    return;
+}
+
 void
 speechd_reload_dead_modules(int sig)
 {
@@ -360,6 +418,21 @@ speechd_reload_dead_modules(int sig)
     while(waitpid(-1, NULL, WNOHANG) > 0);    
 }
 
+void
+speechd_modules_debug(void)
+{
+    /* Redirect output to debug for all modules */
+    g_hash_table_foreach(output_modules, speechd_module_debug, NULL);
+
+}
+
+void
+speechd_modules_nodebug(void)
+{
+    /* Redirect output to normal for all modules */
+    g_hash_table_foreach(output_modules, speechd_module_nodebug, NULL);
+}
+
 
 /* --- SPEECHD START/EXIT FUNCTIONS --- */
 
@@ -373,6 +446,9 @@ speechd_options_init(void)
     SpeechdOptions.conf_file = NULL;
     SpeechdOptions.home_speechd_dir = NULL;
     SpeechdOptions.log_dir = NULL;
+    SpeechdOptions.debug = 0;
+    SpeechdOptions.debug_destination = NULL;
+    debug_logfile = NULL;
     spd_mode = SPD_MODE_DAEMON;    
 }
 
@@ -455,9 +531,18 @@ speechd_init()
       if (SpeechdOptions.home_speechd_dir){
 	SpeechdOptions.log_dir = g_strdup_printf("%s/log/",
 						 SpeechdOptions.home_speechd_dir);
-	mkdir(g_path_get_dirname(SpeechdOptions.log_dir), S_IRWXU);
+	mkdir(SpeechdOptions.log_dir, S_IRWXU);
+	if (!SpeechdOptions.debug_destination){
+	  SpeechdOptions.debug_destination = g_strdup_printf("%slog/debug",
+							     SpeechdOptions.home_speechd_dir);
+	  mkdir(SpeechdOptions.debug_destination, S_IRWXU);
+	}
       }else{
 	SpeechdOptions.log_dir = strdup("/var/log/speech-dispatcher/");
+	if (!SpeechdOptions.debug_destination){
+	  SpeechdOptions.debug_destination = strdup("/var/log/speech-dispatcher/debug");
+	  mkdir(SpeechdOptions.debug_destination, S_IRWXU);
+	}
       }
     }
 
@@ -646,6 +731,9 @@ logging_init(void)
     logfile = stdout;
   }
 
+  if (!debug_logfile)
+    debug_logfile = stdout;
+
   MSG(2,"Speech Dispatcher Logging to file %s", file_name);
   return;
 
@@ -665,15 +753,21 @@ main(int argc, char *argv[])
     /* Initialize threading and thread safety in Glib */
     g_thread_init(NULL);
 
-    speechd_options_init();
+    /* Strip all permisions for 'others' from the files created */
+    umask(007);
 
     /* Initialize logging */
     logfile = stderr;
+    SpeechdOptions.log_level = 1;
     custom_logfile = NULL;
     custom_log_kind = NULL;
 
+    speechd_options_init();
+
     options_parse(argc, argv);
 
+    MSG(1, "Speech Dispatcher "VERSION" starting");
+
     /* Check if there is .speech-dispatcher directory
        in user's home directory. If yes, put everything
        here */
@@ -743,6 +837,8 @@ main(int argc, char *argv[])
 
     speechd_init();
 
+    MSG(1, "Speech Dispatcher will use port %d", SpeechdOptions.port);
+
     /* Initialize socket functionality */
     server_socket = socket(AF_INET, SOCK_STREAM, 0);
     {
@@ -792,7 +888,8 @@ main(int argc, char *argv[])
     SpeechdStatus.max_fd = server_socket;
 
     /* Now wait for clients and requests. */   
-    MSG(1, "Speech Dispatcher waiting for clients ...");
+    MSG(1, "Speech Dispatcher "VERSION" started on port %d and waiting for clients ...",
+	SpeechdOptions.port);
     while (1) {
         testfds = readfds;
 
